OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
    "Updating account failed: " : "Kontoen blev ikke opdateret:",
    "Creating account failed: " : "Oprettelse af konto mislykkedes:",
    "Embedded message %s" : "Indlejret besked %s",
    "Mails" : "Mails",
    "Mail" : "Mail",
    "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "Email addresse",
    "Password" : "Kodeord",
    "Manual" : "Manuel",
    "IMAP Settings" : "IMAP opsætning",
    "IMAP Host" : "IMAP host",
    "IMAP Security" : "IMAP sikkerhed",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP bruger",
    "IMAP Password" : "IMAP kodeord",
    "SMTP Settings" : "SMTP opsætnin",
    "SMTP Host" : "SMTP host",
    "SMTP Security" : "SMTP sikkerhed",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP bruger",
    "SMTP Password" : "SMTP kodeord",
    "Save" : "Gem",
    "Connect" : "Tilslut",
    "Add mail account" : "Tilføj mail konto",
    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
    "Register as application for mail links" : "Registrer som program til at åbne mail links",
    "From" : "Fra",
    "Select account" : "Vælg konto",
    "To" : "Til",
    "Contact or email address …" : "Kontakt eller email…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Ingen kontakter.",
    "Bcc" : "Bcc",
    "Subject" : "Emne",
    "Subject …" : "Emne…",
    "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
    "The following recipients do not have a PGP key: {recipients}." : "Følgende modtagere har ikke en PGP nøgle: {recipients}.",
    "Write message …" : "Skriv en besked…",
    "Saving draft …" : "Gemmer kladde…",
    "Draft saved" : "Kladde gemt",
    "Upload attachment" : "Upload vedhæftning",
    "Add attachment from Files" : "Vedhæft fra filer",
    "Enable formatting" : "Aktiver formatering",
    "Encrypt message with Mailvelope" : "Kryptér meddelelse med Mailvelope",
    "Uploading attachments …" : "Uploader vedhæftninger",
    "Sending …" : "Sender ...",
    "Go back" : "Gå tilbage",
    "Retry" : "Prøv igen",
    "Message sent!" : "Beskeden blev sendt!",
    "Write another message" : "Skriv en ny besked…",
    "Send" : "Send",
    "Encrypt and send" : "Kryptér og send",
    "Send unencrypted" : "Send ukrypteret",
    "Uploading {percent}% …" : "Uploader {percent}%…",
    "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
    "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
    "Plain text" : "Klartekst",
    "Rich text" : "Formateret tekst",
    "No messages in this folder" : "Ingen beskeder i denne mappe",
    "No messages" : "Ingen beskeder",
    "Draft: " : "Kladde:",
    "Mark unread" : "Marker som ulæst",
    "Mark read" : "Marker som læst",
    "Unselect" : "Fravælg",
    "Select" : "Vælg",
    "Delete" : "Slet",
    "Loading messages" : "Henter beskedder",
    "Important" : "Vigtigt",
    "Favorites" : "Favoritter",
    "Other" : "Andet",
    "Attachments" : "Vedhæftede filer",
    "Import into calendar" : "Importere til kalender",
    "Download attachment" : "Hent vedhæftning",
    "Save to Files" : "Gem til filer",
    "Unnamed" : "Unavngiven",
    "Embedded message" : "Indlejret besked",
    "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
    "Save all to Files" : "Gem alle filer",
    "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
    "Show images from this sender" : "Vis billeder fra denne afsender",
    "New message" : "Ny besked",
    "Settings" : "Indstillinger",
    "Quota" : "Kvote",
    "Account settings" : "Kontoindstillinger",
    "Add folder" : "Tilføj mappe",
    "Saving" : "Gemmer",
    "Move down" : "Flyt ned",
    "Remove account" : "Fjern konto",
    "Loading …" : "Indlæser…",
    "Cancel" : "Annullér",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Fold mapper sammen",
    "Mark all as read" : "Markér alle som læst",
    "Add subfolder" : "Tilføj undermappe",
    "Edit name" : "Rediger navn",
    "Clear cache" : "Ryd cache",
    "Delete folder" : "Slet mappe",
    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
    "Not found" : "Ikke fundet",
    "Could not load your draft" : "Kladden kunne ikke indlæses",
    "Could not load original message" : "Den originale besked kunne ikke indlæses",
    "No message selected" : "Ingen besked valgt",
    "Signature" : "Underskrift",
    "Reply" : "Besvar",
    "Forward" : "Videresend",
    "View source" : "Vis kildekode",
    "Message source" : "Beskedens kildekode",
    "Airplane" : "Fly",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
    "Train" : "Tog",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
    "General" : "Generelt",
    "Email address" : "E-mailadresse",
    "IMAP" : "IMAP",
    "User" : "ruger",
    "Host" : "Vært",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
    "Compose new message" : "Skriv en ny meddelelse",
    "Newer message" : "Nyere besked",
    "Older message" : "Ældre besked",
    "Toggle star" : "Toggle stjerne",
    "Toggle unread" : "Toggle læst",
    "Search" : "Søg",
    "Refresh" : "Opdatér",
    "Connect your mail account" : "Forbind din mail konto",
    "Unexpected error during account creation" : "Uventet fejl under oprettelse af konto",
    "All" : "Alle",
    "Archive" : "Arkivér",
    "Drafts" : "Udkast",
    "Priority inbox" : "Prioriteret indbakke",
    "All inboxes" : "Alle indbakker",
    "Inbox" : "Indbakke",
    "Junk" : "Junk",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "Error while sharing file" : "Fejl ved deling af fil",
    "{from}\n{subject}" : "{fra}\n{emne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
    "Could not load your message" : "Din besked kunne ikke indlæses",
    "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
    "Could not load the message" : "Beskeden kunne ikke indlæses",
    "Error loading message" : "Fejl under indlæsning af besked",
    "Forwarding to %s" : "Videre send til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
    "Redirect" : "Omdiriger",
    "The link leads to %s" : "Linket fører til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Videre til %s"
},
"nplurals=2; plural=(n != 1);");
